import { DEFAULT_NETWORK, getProtocolInitializer, networkPlatformConfigs, } from '@wormhole-foundation/connect-sdk';
import { SolanaChain } from './chain';
import { SolanaUtils } from './platformUtils';
import { Connection } from '@solana/web3.js';
// forces SolanaPlatform to implement Platform
var _ = SolanaPlatform;
/**
 * @category Solana
 */
export var SolanaPlatform;
(function (SolanaPlatform) {
    SolanaPlatform.platform = 'Solana';
    SolanaPlatform.network = DEFAULT_NETWORK;
    SolanaPlatform.conf = networkPlatformConfigs(SolanaPlatform.network, SolanaPlatform.platform);
    const registeredProtocols = new Map();
    SolanaPlatform.nativeTokenId = SolanaUtils.nativeTokenId, SolanaPlatform.isNativeTokenId = SolanaUtils.isNativeTokenId, SolanaPlatform.isSupportedChain = SolanaUtils.isSupportedChain, SolanaPlatform.getDecimals = SolanaUtils.getDecimals, SolanaPlatform.getBalance = SolanaUtils.getBalance, SolanaPlatform.getBalances = SolanaUtils.getBalances, SolanaPlatform.sendWait = SolanaUtils.sendWait, SolanaPlatform.getCurrentBlock = SolanaUtils.getCurrentBlock, SolanaPlatform.chainFromChainId = SolanaUtils.chainFromChainId, SolanaPlatform.chainFromRpc = SolanaUtils.chainFromRpc;
    function setConfig(_network, _conf) {
        SolanaPlatform.conf = _conf ? _conf : networkPlatformConfigs(SolanaPlatform.network, SolanaPlatform.platform);
        SolanaPlatform.network = _network;
        return SolanaPlatform;
    }
    SolanaPlatform.setConfig = setConfig;
    function getRpc(chain, commitment = 'confirmed') {
        const rpcAddress = SolanaPlatform.conf[chain].rpc;
        return new Connection(rpcAddress, commitment);
    }
    SolanaPlatform.getRpc = getRpc;
    function getChain(chain) {
        if (chain in SolanaPlatform.conf)
            return new SolanaChain(SolanaPlatform.conf[chain]);
        throw new Error('No configuration available for chain: ' + chain);
    }
    SolanaPlatform.getChain = getChain;
    function getProtocol(protocol) {
        return getProtocolInitializer(SolanaPlatform.platform, protocol);
    }
    SolanaPlatform.getProtocol = getProtocol;
    async function getWormholeCore(rpc) {
        return getProtocol('WormholeCore').fromRpc(rpc, SolanaPlatform.conf);
    }
    SolanaPlatform.getWormholeCore = getWormholeCore;
    async function getTokenBridge(rpc) {
        return getProtocol('TokenBridge').fromRpc(rpc, SolanaPlatform.conf);
    }
    SolanaPlatform.getTokenBridge = getTokenBridge;
    async function parseTransaction(chain, rpc, tx) {
        const core = await getWormholeCore(rpc);
        return core.parseTransaction(tx);
    }
    SolanaPlatform.parseTransaction = parseTransaction;
})(SolanaPlatform || (SolanaPlatform = {}));
//# sourceMappingURL=platform.js.map